Skip to main contentCrate pubky_app_specs
Source - limits
- Validation limits for pubky-app-specs data models.
- traits
- ParsedUri
- PubkyAppBlob
- Represents a blob, which backs a file uploaded by the user.
URI: /pub/pubky.app/blobs/:blob_id
- PubkyAppBookmark
- Represents raw homeserver bookmark with id
URI: /pub/pubky.app/bookmarks/:bookmark_id
- PubkyAppCollectionContent
- Typed JSON envelope stored in
PubkyAppPost::content when kind == Collection. - PubkyAppFeed
- Represents a feed configuration.
- PubkyAppFile
- Represents a file uploaded by the user.
URI: /pub/pubky.app/files/:file_id
- PubkyAppFollow
- Represents raw homeserver follow object with timestamp
- PubkyAppLastRead
- Represents the last read timestamp for notifications.
URI: /pub/pubky.app/last_read
- PubkyAppMute
- Represents raw homeserver Mute object with timestamp
URI: /pub/pubky.app/mutes/:user_id
- PubkyAppPost
- Represents raw post in homeserver with content and kind
URI: /pub/pubky.app/posts/:post_id
Where post_id is CrockfordBase32 encoding of timestamp
- PubkyAppPostEmbed
- Represents embedded content within a post
- PubkyAppTag
- Represents raw homeserver tag with id
URI: /pub/pubky.app/tags/:tag_id
- PubkyAppUser
- URI: /pub/pubky.app/profile.json
- PubkyAppUserLink
- Represents a user’s single link with a title and URL.
- PubkyId
- Represents user data with name, bio, image, links, and status.
- ValidationLimits
- Bundled validation limits for quick consumption.
- PubkyAppFeedLayout
- Enum representing the layout of the feed.
- PubkyAppFeedReach
- Enum representing the reach of the feed.
- PubkyAppFeedSort
- Enum representing the sort order of the feed.
- PubkyAppObject
- A unified enum wrapping all PubkyApp objects.
- PubkyAppPostKind
- Represents the type of pubky-app posted data
Used primarily to best display the content in UI
- Resource
- VALIDATION_LIMITS
- All validation limits in a single bundle.
- VALID_MIME_TYPES
- Valid MIME types for file attachments.
- APP_PATH
- PROTOCOL
- PUBLIC_PATH
- VERSION
- base_uri_builder
- blob_uri_builder
- Builds a Blob URI of the form “pubky://<author_id>/pub/pubky.app/blobs/<blob_id>”
- bookmark_uri_builder
- Builds a Bookmark URI of the form “pubky://<author_id>/pub/pubky.app/bookmarks/<bookmark_id>”
- feed_uri_builder
- Builds a Feed URI of the form “pubky://<author_id>/pub/pubky.app/feeds/<feed_id>”
- file_uri_builder
- Builds a File URI of the form “pubky://<author_id>/pub/pubky.app/files/<file_id>”
- follow_uri_builder
- Builds a Follow URI of the form “pubky://<author_id>/pub/pubky.app/follows/<follow_id>”
- last_read_uri_builder
- Builds a LastRead URI of the form “pubky://<author_id>/pub/pubky.app/last_read”
- mute_uri_builder
- Builds a Mute URI of the form “pubky://<author_id>/pub/pubky.app/mutes/<mute_id>”
- post_uri_builder
- Builds a Post URI of the form “pubky://<author_id>/pub/pubky.app/posts/<post_id>”
- tag_uri_builder
- Builds a Tag URI of the form “pubky://<author_id>/pub/pubky.app/tags/<tag_id>”
- user_uri_builder
- Builds an User URI of the form “pubky://<user_pubky_id>/pub/pubky.app/profile.json”
- validate_crockford_id
- Validates structural correctness of a Crockford Base32-encoded ID (13
characters, decodes to 8 bytes). Returns the decoded bytes on success.